==> aws-sdk-cpp-kinesis-1.11.657-1-x86_64.pkg.tar.zst: usr/include/aws/kinesisanalyticsv2/KinesisAnalyticsV2Errors.h <==
﻿/**
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * SPDX-License-Identifier: Apache-2.0.
 */

#pragma once

#include <aws/core/client/AWSError.h>
#include <aws/core/client/CoreErrors.h>
#include <aws/kinesisanalyticsv2/KinesisAnalyticsV2_EXPORTS.h>

namespace Aws
{
namespace KinesisAnalyticsV2
{
enum class KinesisAnalyticsV2Errors
{
  //From Core//
  //////////////////////////////////////////////////////////////////////////////////////////
  INCOMPLETE_SIGNATURE = 0,
  INTERNAL_FAILURE = 1,
  INVALID_ACTION = 2,
  INVALID_CLIENT_TOKEN_ID = 3,
  INVALID_PARAMETER_COMBINATION = 4,
  INVALID_QUERY_PARAMETER = 5,
  INVALID_PARAMETER_VALUE = 6,
  MISSING_ACTION = 7, // SDK should never allow
  MISSING_AUTHENTICATION_TOKEN = 8, // SDK should never allow
  MISSING_PARAMETER = 9, // SDK should never allow
  OPT_IN_REQUIRED = 10,
  REQUEST_EXPIRED = 11,
  SERVICE_UNAVAILABLE = 12,
  THROTTLING = 13,
  VALIDATION = 14,
  ACCESS_DENIED = 15,
  RESOURCE_NOT_FOUND = 16,
  UNRECOGNIZED_CLIENT = 17,
  MALFORMED_QUERY_STRING = 18,
  SLOW_DOWN = 19,
  REQUEST_TIME_TOO_SKEWED = 20,
  INVALID_SIGNATURE = 21,
  SIGNATURE_DOES_NOT_MATCH = 22,
  INVALID_ACCESS_KEY_ID = 23,
  REQUEST_TIMEOUT = 24,
  NETWORK_CONNECTION = 99,

  UNKNOWN = 100,
  ///////////////////////////////////////////////////////////////////////////////////////////

  CODE_VALIDATION= static_cast<int>(Aws::Client::CoreErrors::SERVICE_EXTENSION_START_RANGE) + 1,
  CONCURRENT_MODIFICATION,
  INVALID_APPLICATION_CONFIGURATION,
  INVALID_ARGUMENT,
  INVALID_REQUEST,
  LIMIT_EXCEEDED,
  RESOURCE_IN_USE,
  RESOURCE_PROVISIONED_THROUGHPUT_EXCEEDED,
  TOO_MANY_TAGS,
  UNABLE_TO_DETECT_SCHEMA,
  UNSUPPORTED_OPERATION
};

class AWS_KINESISANALYTICSV2_API KinesisAnalyticsV2Error : public Aws::Client::AWSError<KinesisAnalyticsV2Errors>
{
public:
  KinesisAnalyticsV2Error() {}
  KinesisAnalyticsV2Error(const Aws::Client::AWSError<Aws::Client::CoreErrors>& rhs) : Aws::Client::AWSError<KinesisAnalyticsV2Errors>(rhs) {}
  KinesisAnalyticsV2Error(Aws::Client::AWSError<Aws::Client::CoreErrors>&& rhs) : Aws::Client::AWSError<KinesisAnalyticsV2Errors>(rhs) {}
  KinesisAnalyticsV2Error(const Aws::Client::AWSError<KinesisAnalyticsV2Errors>& rhs) : Aws::Client::AWSError<KinesisAnalyticsV2Errors>(rhs) {}
  KinesisAnalyticsV2Error(Aws::Client::AWSError<KinesisAnalyticsV2Errors>&& rhs) : Aws::Client::AWSError<KinesisAnalyticsV2Errors>(rhs) {}

  template <typename T>
  T GetModeledError();
};

namespace KinesisAnalyticsV2ErrorMapper
{
  AWS_KINESISANALYTICSV2_API Aws::Client::AWSError<Aws::Client::CoreErrors> GetErrorForName(const char* errorName);
}

} // namespace KinesisAnalyticsV2
} // namespace Aws

==> aws-sdk-cpp-kinesis-1.11.710-1-x86_64.pkg.tar.zst: usr/include/aws/kinesisanalyticsv2/KinesisAnalyticsV2Errors.h <==
﻿/**
 * Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 * SPDX-License-Identifier: Apache-2.0.
 */

#pragma once

#include <aws/core/client/AWSError.h>
#include <aws/core/client/CoreErrors.h>
#include <aws/kinesisanalyticsv2/KinesisAnalyticsV2_EXPORTS.h>

namespace Aws {
namespace KinesisAnalyticsV2 {
enum class KinesisAnalyticsV2Errors {
  // From Core//
  //////////////////////////////////////////////////////////////////////////////////////////
  INCOMPLETE_SIGNATURE = 0,
  INTERNAL_FAILURE = 1,
  INVALID_ACTION = 2,
  INVALID_CLIENT_TOKEN_ID = 3,
  INVALID_PARAMETER_COMBINATION = 4,
  INVALID_QUERY_PARAMETER = 5,
  INVALID_PARAMETER_VALUE = 6,
  MISSING_ACTION = 7,                // SDK should never allow
  MISSING_AUTHENTICATION_TOKEN = 8,  // SDK should never allow
  MISSING_PARAMETER = 9,             // SDK should never allow
  OPT_IN_REQUIRED = 10,
  REQUEST_EXPIRED = 11,
  SERVICE_UNAVAILABLE = 12,
  THROTTLING = 13,
  VALIDATION = 14,
  ACCESS_DENIED = 15,
  RESOURCE_NOT_FOUND = 16,
  UNRECOGNIZED_CLIENT = 17,
  MALFORMED_QUERY_STRING = 18,
  SLOW_DOWN = 19,
  REQUEST_TIME_TOO_SKEWED = 20,
  INVALID_SIGNATURE = 21,
  SIGNATURE_DOES_NOT_MATCH = 22,
  INVALID_ACCESS_KEY_ID = 23,
  REQUEST_TIMEOUT = 24,
  NETWORK_CONNECTION = 99,

  UNKNOWN = 100,
  ///////////////////////////////////////////////////////////////////////////////////////////

  CODE_VALIDATION = static_cast<int>(Aws::Client::CoreErrors::SERVICE_EXTENSION_START_RANGE) + 1,
  CONCURRENT_MODIFICATION,
  INVALID_APPLICATION_CONFIGURATION,
  INVALID_ARGUMENT,
  INVALID_REQUEST,
  LIMIT_EXCEEDED,
  RESOURCE_IN_USE,
  RESOURCE_PROVISIONED_THROUGHPUT_EXCEEDED,
  TOO_MANY_TAGS,
  UNABLE_TO_DETECT_SCHEMA,
  UNSUPPORTED_OPERATION
};

class AWS_KINESISANALYTICSV2_API KinesisAnalyticsV2Error : public Aws::Client::AWSError<KinesisAnalyticsV2Errors> {
 public:
  KinesisAnalyticsV2Error() {}
  KinesisAnalyticsV2Error(const Aws::Client::AWSError<Aws::Client::CoreErrors>& rhs)
      : Aws::Client::AWSError<KinesisAnalyticsV2Errors>(rhs) {}
  KinesisAnalyticsV2Error(Aws::Client::AWSError<Aws::Client::CoreErrors>&& rhs) : Aws::Client::AWSError<KinesisAnalyticsV2Errors>(rhs) {}
  KinesisAnalyticsV2Error(const Aws::Client::AWSError<KinesisAnalyticsV2Errors>& rhs)
      : Aws::Client::AWSError<KinesisAnalyticsV2Errors>(rhs) {}
  KinesisAnalyticsV2Error(Aws::Client::AWSError<KinesisAnalyticsV2Errors>&& rhs) : Aws::Client::AWSError<KinesisAnalyticsV2Errors>(rhs) {}

  template <typename T>
  T GetModeledError();
};

namespace KinesisAnalyticsV2ErrorMapper {
AWS_KINESISANALYTICSV2_API Aws::Client::AWSError<Aws::Client::CoreErrors> GetErrorForName(const char* errorName);
}

}  // namespace KinesisAnalyticsV2
}  // namespace Aws
